[−][src]Enum tmi_parser::Message
Possible types of TMI messages.
Unrecognized messages are handled by the associated [parse] function.
Tags are always treated as Optional even on messages that require them. Actually, tags validation should be done by the user code.
Consider changing simple enum structs to enum tuples.
Variants
Represents a ping request message.
PING :<endpoint>
Represents a pong response message.
PONG :<endpoint>
Represents a capability request message.
CAP REQ :<capability>
Fields of CapReq
req: &'a strRepresents a capability acknowledgement message.
:<endpoint> CAP * ACK :<capability>
Fields of CapAck
req: &'a strRepresents a password authentication message.
PASS <password>
PASS oauth:<token> (using Twitch OAuth tokens)
Fields of Pass
pass: &'a strRepresents a nickname authentication message.
NICK <user>
Fields of Nick
nick: &'a strRepresents a join command message.
JOIN #<channel>
Fields of Join
chan: &'a strRepresents a part command message.
PART #<channel>
Fields of Part
chan: &'a strRepresents a privmsg command message.
[@<tags>] PRIVMSG #<channel> :<message>
Represents a clearchat command message.
[@<tags>] :<endpoint> CLEARCHAT #<channel> [:<user>]
Represents a clearmsg command message.
[@<tags>] :<endpoint> CLEARMSG #<channel> [:<message>]
Represents a hosttarget start message.
:<endpoint> HOSTTARGET #<host> :<channel> [<viewers>]
Represents a hosttarget end message.
:<endpoint> HOSTTARGET #<host> :- [<viewers>]
Represents a notice message.
[@<tags>] :<endpoint> NOTICE #<channel> :<message>
Represents a reconnect request message.
RECONNECT
Represents a roomstate message.
[@<tags>] :<endpoint> ROOMSTATE #<channel>
Fields of Roomstate
chan: &'a strRepresents a usernotice message.
[@<tags>] :<endpoint> USERNOTICE #<channel> :<message>
Represents a userstate message.
[@<tags>] :<endpoint> USERSTATE #<channel>
Fields of Userstate
chan: &'a strRepresents a global userstate message.
[@<tags>] :<endpoint> GLOBALUSERSTATE
Fields of GlobalUserstate
Implementations
impl<'a> Message<'a>[src]
pub fn parse(msg: &'a str) -> Result<Message<'_>>[src]
Parses a [& str] slice and returns a Message if successful, otherwise an [io::Error].
Examples
let s = ":tmi.twitch.tv CLEARCHAT #dallas :ronni"; let msg = tmi_parser::Message::parse(s);